@@ -844,10 +844,11 @@ indexing_tree_file_is_filtered (TrackerIndexingTree *tree,
 gboolean
 tracker_indexing_tree_file_is_indexable (TrackerIndexingTree *tree,
                                          GFile               *file,
-                                         GFileInfo           *info)
+                                         GFileInfo           *file_info)
 {
 	TrackerFilterType filter;
 	TrackerDirectoryFlags config_flags;
+	g_autoptr (GFileInfo) info = NULL;
 	GFile *config_file;
 	GFileType file_type;
 
@@ -860,6 +861,8 @@ tracker_indexing_tree_file_is_indexable (TrackerIndexingTree *tree,
 		return FALSE;
 	}
 
+	g_set_object (&info, file_info);
+
 	if (info == NULL) {
 		info = g_file_query_info (file,
 		                          G_FILE_ATTRIBUTE_STANDARD_TYPE ","
