@@ -278,7 +278,8 @@ notify_task_finish (TrackerExtractTask *task,
 
 static gboolean
 get_file_metadata (TrackerExtractTask  *task,
-                   TrackerExtractInfo **info_out)
+                   TrackerExtractInfo **info_out,
+                   GError             **error)
 {
 	TrackerExtractInfo *info;
 	GFile *file;
@@ -301,7 +302,7 @@ get_file_metadata (TrackerExtractTask  *task,
 		g_debug ("Using %s...",
 		         g_module_name (task->module));
 
-		task->success = (task->func) (info);
+		task->success = (task->func) (info, error);
 	} else {
 		TrackerResource *resource;
 
@@ -463,6 +464,7 @@ get_metadata (TrackerExtractTask *task)
 {
 	TrackerExtractPrivate *priv = TRACKER_EXTRACT_GET_PRIVATE (task->extract);
 	TrackerExtractInfo *info;
+	GError *error = NULL;
 
 #ifdef THREAD_ENABLE_TRACE
 	g_debug ("Thread:%p --> '%s': Collected metadata",
@@ -494,17 +496,19 @@ get_metadata (TrackerExtractTask *task)
 #endif
 
 	if (!filter_module (task->extract, task->module) &&
-	    get_file_metadata (task, &info)) {
+	    get_file_metadata (task, &info, &error)) {
 		g_task_return_pointer (G_TASK (task->res), info,
 		                       (GDestroyNotify) tracker_extract_info_unref);
-		extract_task_free (task);
 	} else {
-		g_task_return_new_error (G_TASK (task->res),
-		                         tracker_extract_error_quark (),
-		                         TRACKER_EXTRACT_ERROR_NO_EXTRACTOR,
-		                         "Could not get any metadata for uri:'%s' and mime:'%s'",
-		                         task->file, task->mimetype);
-		extract_task_free (task);
+		if (error) {
+			g_task_return_error (G_TASK (task->res), error);
+		} else {
+			g_task_return_new_error (G_TASK (task->res),
+			                         tracker_extract_error_quark (),
+			                         TRACKER_EXTRACT_ERROR_NO_EXTRACTOR,
+			                         "Could not get any metadata for uri:'%s' and mime:'%s'",
+			                         task->file, task->mimetype);
+		}
 	}
 
 #ifdef G_ENABLE_DEBUG
@@ -517,6 +521,8 @@ get_metadata (TrackerExtractTask *task)
 	}
 #endif
 
+	extract_task_free (task);
+
 	return FALSE;
 }
 
@@ -559,6 +565,17 @@ dispatch_task_cb (TrackerExtractTask *task)
 
 	priv = TRACKER_EXTRACT_GET_PRIVATE (task->extract);
 
+	task->graph = tracker_extract_module_manager_get_graph (task->mimetype);
+	if (!task->graph) {
+		g_task_return_new_error (G_TASK (task->res),
+		                         tracker_extract_error_quark (),
+		                         TRACKER_EXTRACT_ERROR_NO_EXTRACTOR,
+		                         "Unknown target graph for uri:'%s' and mime:'%s'",
+		                         task->file, task->mimetype);
+		extract_task_free (task);
+		return FALSE;
+	}
+
 	if (!task->mimetype) {
 		g_task_return_new_error (G_TASK (task->res),
 		                         tracker_extract_error_quark (),
@@ -572,8 +589,6 @@ dispatch_task_cb (TrackerExtractTask *task)
 		                                                          &task->func);
 	}
 
-	task->graph = tracker_extract_module_manager_get_graph (task->mimetype);
-
 	async_queue = g_hash_table_lookup (priv->single_thread_extractors,
 	                                   task->module);
 
@@ -688,19 +703,32 @@ tracker_extract_get_metadata_by_cmdline (TrackerExtract             *object,
 	                                                          NULL,
 	                                                          &task->func);
 
+	if (!tracker_seccomp_init ())
+		g_assert_not_reached ();
+
 	if (!filter_module (object, task->module) &&
-	    get_file_metadata (task, &info)) {
+	    get_file_metadata (task, &info, NULL)) {
 		resource = tracker_extract_info_get_resource (info);
 	}
 
 	if (resource) {
 		if (output_format == TRACKER_SERIALIZATION_FORMAT_SPARQL) {
 			char *text;
+			g_autoptr (TrackerResource) file_resource = NULL;
 
-			/* If this was going into the tracker-store we'd generate a unique ID
-			 * here, so that the data persisted across file renames.
+			/* Set up the corresponding nfo:FileDataObject resource appropriately,
+			 * so the SPARQL we generate is valid according to Nepomuk.
 			 */
-			tracker_resource_set_identifier (resource, uri);
+			file_resource = tracker_resource_get_first_relation (resource, "nie:isStoredAs");
+
+			if (file_resource) {
+				g_object_ref (file_resource);
+			} else {
+				file_resource = tracker_resource_new (uri);
+				tracker_resource_set_relation (resource, "nie:isStoredAs", file_resource);
+			}
+
+			tracker_resource_add_uri (file_resource, "rdf:type", "nfo:FileDataObject");
 
 			text = tracker_resource_print_sparql_update (resource, NULL, NULL);
 
