@@ -701,10 +701,26 @@ tracker_miner_manager_get_running (TrackerMinerManager *manager)
 
 	g_variant_get (v, "(as)", &iter);
 	while (g_variant_iter_loop (iter, "&s", &str)) {
+		gboolean available = FALSE;
+		GList *l;
+
 		if (!g_str_has_prefix (str, prefix)) {
 			continue;
 		}
 
+		/* Skip unlisted miners */
+		for (l = priv->miners; l; l = l->next) {
+			MinerData *data = l->data;
+
+			if (g_strcmp0 (data->dbus_name, str) == 0) {
+				available = TRUE;
+				break;
+			}
+		}
+
+		if (!available)
+			continue;
+
 		list = g_slist_prepend (list, g_strdup (str));
 	}
 
@@ -733,9 +749,9 @@ check_file (GFile    *file,
 	priv = tracker_miner_manager_get_instance_private (manager);
 
 	key_file = g_key_file_new ();
-	g_key_file_load_from_file (key_file, path, G_KEY_FILE_NONE, &error);
 
-	if (error) {
+	if (!g_key_file_load_from_file (key_file, path, G_KEY_FILE_NONE, &error)) {
+		g_assert (error != NULL);
 		g_warning ("Error parsing miner .desktop file: %s", error->message);
 		g_error_free (error);
 		g_key_file_free (key_file);
